from Globals import DTMLFile
from cgi import escape
import string
from OFS.CopySupport import cookie_path

class base:
    """Mixin class used to provide common functionality."""

    search = DTMLFile('issue_search', globals())
    remote = DTMLFile('remote', globals())
    issue_tree = DTMLFile('issue_tree', globals())
    issue_listing = DTMLFile('issue_listing', globals())
    standard_html_footer = DTMLFile('standard_html_footer', globals())

    def render_breadcrumbs(self):
        """Renders breadcrumbs."""
        parents = self.REQUEST['PARENTS'][:]
        breadcrumbs = []
        for parent in parents:
            breadcrumbs.append("""<a href="%s">%s</a>""" % \
             (parent.absolute_url(), escape(parent.get_title())))
            if parent.meta_type == 'Issue Manager':
                break
        breadcrumbs.reverse()
        return """<div id="breadcrumbs">""" + \
               string.join(breadcrumbs, ' :: ') + \
               """</div>"""

    def get_title(self):
        """Returns a descriptive title."""
        if self.title:
            return self.title
        else:
            return self.meta_type

    def get_search_results(self):
        """Returns search results, based on REQUEST."""
        search = self.REQUEST['search_string']
        return self.Catalog(get_all_text=search)

    def get_all_text(self):
        """Returns all text on the object."""
        return self.title + " " + self.contents

    def manage_edit(self, title, contents, format, REQUEST=None):
        """Edits the object."""
        self.title = title
        self.contents = contents
        self.format = format
        self.index_object()
        if REQUEST is not None:
            REQUEST.RESPONSE.redirect(self.absolute_url())

    def get_issues(self):
        """Returns a list of the Issues contained."""
        return self.objectValues('Issue')

    def get_number_of_issues(self):
        """Returns the number of Issues contained."""
        return len(self.get_issues())

    def manage_cut(self, ids=None):
        """Cuts selected objects."""
        copy_data = self.manage_cutObjects(ids=ids)
        self.REQUEST.RESPONSE.setCookie('__cp', copy_data,
                                        path='%s' % cookie_path(self.REQUEST))
        self.REQUEST.RESPONSE.redirect(self.absolute_url())

    def manage_paste(self):
        """Pastes cut objects."""
        self.manage_pasteObjects(cb_copy_data=self.REQUEST['__cp'])
        self.REQUEST.RESPONSE.redirect(self.absolute_url())

    def manage_delete(self, ids=[]):
        """Deletes the specified objects."""
        self.manage_delObjects(ids=ids)
        self.REQUEST.RESPONSE.redirect(self.absolute_url())
